@@ -274,7 +274,7 @@ void MusicActionMessage::Handle(){
 
 		this->mt->musicActionsBuffer.push_back(0x03);//message type
 
-		switch(Preferences::Inst().GetTimbre()){
+		switch(this->timbre){
 			default:
 			case SINE_PLUS_ADSR:
 				this->mt->musicActionsBuffer.push_back(0x00);
