@@ -62,7 +62,9 @@ void MainWindow::ShowNetworkSettingsDialog(){
 
 
 
-MainWindow::MainWindow(){
+MainWindow::MainWindow() :
+		BasicWindow(true)//pass true because this is a root wondow, it will not be closed by backspace key
+{
 	this->set_default_size(800, 480);
 
 	Gtk::Box *mainBox = new Gtk::VBox();
