@@ -38,15 +38,17 @@ THE SOFTWARE. */
 #include <gtkmm/notebook.h>
 #include <gtkmm/menu.h>
 
+
+
 #include <ting/types.hpp>
 #include <ting/Singleton.hpp>
 #include <ting/Signal.hpp>
 #include <aumiks/synth/synth.hpp>
 
-#include "MainMenuView.hpp"
-#include "ThereminView.hpp"
-#include "KeyboardView.hpp"
-#include "ListenView.hpp"
+#include "BasicWindow.hpp"
+#include "ThereminWindow.hpp"
+#include "KeyboardWindow.hpp"
+#include "ListenWindow.hpp"
 #include "Preferences.hpp"
 
 
@@ -57,32 +59,12 @@ class MainThread;
 
 class MainWindow :
 		public ting::Singleton<MainWindow>,
-		public
-#ifndef M_NON_MAEMO_LINUX
-		Hildon::Window
-#else
-		Gtk::Window
-#endif
+		public BasicWindow
 {
-	bool isFullscreen;
+	ThereminWindow thereminWindow;
+	ListenWindow listenWindow;
+	KeyboardWindow keyboardWindow;
 
-	Gtk::Menu mainMenu;
-	Gtk::MenuItem optionsMenuItem;
-	Gtk::MenuItem exitMenuItem;
-	Gtk::MenuItem aboutMenuItem;
-
-	Gtk::Notebook notebook;
-
-	MainMenuView mainMenuView;
-	ThereminView thereminView;
-	ListenView listenView;
-	KeyboardView keyboardView;
-
-	ting::Signal0 openOptionsSignal;
-
-	void OpenOptionsDialog(){
-		this->openOptionsSignal.Emit();
-	}
 
 public:
 	MainWindow();
@@ -90,49 +72,24 @@ public:
 //		TRACE(<< "~MainWindow(): invoked" << std::endl)
 	}
 
-	void ShowMainMenuScreen(){
-		this->notebook.set_current_page(0);
-		this->openOptionsSignal.DisconnectAll();
-		this->optionsMenuItem.set_sensitive(false);
-	}
-
 	void ShowThereminScreen(){
-		this->notebook.set_current_page(1);
-		this->openOptionsSignal.DisconnectAll();
-		this->openOptionsSignal.Connect(
-				&this->thereminView,
-				&ThereminView::ShowOptionsDialog
-			);
-		this->optionsMenuItem.set_sensitive(true);
+		this->thereminWindow.show();
 	}
 
 	void ShowListenOthersScreen(){
-		this->notebook.set_current_page(2);
-		this->openOptionsSignal.DisconnectAll();
-		this->optionsMenuItem.set_sensitive(false);
+		this->listenWindow.show();
 
-		this->listenView.OnNextButtonClicked();//send first "next" command to server
+		//send first "next" command to server
+		this->listenWindow.SendNextCommandToServer();
 	}
 
 	void ShowKeyboardScreen(){
-		this->notebook.set_current_page(3);
-		this->openOptionsSignal.DisconnectAll();
-		this->openOptionsSignal.Connect(
-				&this->keyboardView,
-				&KeyboardView::ShowOptionsDialog
-			);
-		this->optionsMenuItem.set_sensitive(true);
+		this->keyboardWindow.show();
 	}
 
-	bool OnKeyPress(GdkEventKey* event);
-	void OnKeyPress_Notify(GdkEventKey* event);
-
-	void ShowAboutDialog();
-
+	void ShowNetworkSettingsDialog();
+	
 	void Exit();
-
-private:
-	void ToggleFullscreen();
 };
 
 
