@@ -33,6 +33,7 @@ THE SOFTWARE. */
 #include <ting/types.hpp>
 #include <ting/Singleton.hpp>
 #include <ting/Thread.hpp>
+#include <ting/utils.hpp>
 
 
 #include "utils.hpp"
@@ -54,10 +55,13 @@ public:
 			serverPort(0),
 			
 			numOctaves(1),
-			basePitch(12 * 4),//A4
+			basePitch(12 * 3),//A3
 			lockCurrentOctave(true),
 			timbre(SINE_PLUS_ADSR),
 
+			kbScrPos(14 * 3),// 3-rd octave
+			kbTimbre(SINE_PLUS_ADSR),
+
 			autologin(false),
 			broadcast(false)
 	{}
@@ -81,22 +85,9 @@ private:
 	ting::uint numOctaves;
 
 	ting::uint basePitch;//step number starting from A0 (27.5Hz)
-	float baseFreq;//related to basePitch
 
 	bool lockCurrentOctave;
 
-public:
-	enum E_Timbre{
-		SINE_PLUS_ADSR,
-		PLUCKED_STRING,
-		TROMBONE,
-		CLARINET,
-
-		UNKNOWN, //NOTE: UNKNOWN must be last timbre in the list!!!
-
-		NUM_TIMBRES
-	};
-
 private:
 	E_Timbre timbre;
 public:
@@ -114,16 +105,9 @@ public:
 		return this->basePitch;
 	}
 
-	inline float GetBaseFreq()const{
-		return this->baseFreq;
-	}
-	
 	void SetBasePitch(ting::uint newBasePitch){
 		this->basePitch = newBasePitch;
 		this->ClampBasePitch();
-
-		//set base freq
-		this->baseFreq = PitchToFreq(this->basePitch);
 	}
 
 	inline bool GetLockCurrentOctave()const{
@@ -142,9 +126,6 @@ public:
 		this->timbre = newTimbre;
 	}
 
-	static std::string TimbreTypeToName(Preferences::E_Timbre timbre);
-	static Preferences::E_Timbre TimbreNameToType(std::string name);
-
 
 
 private:
@@ -154,6 +135,33 @@ private:
 
 
 
+	//keyboard view settings
+private:
+	ting::uint kbScrPos;//screen position
+
+	E_Timbre kbTimbre;
+
+public:
+	inline ting::uint GetKbScrPos()const{
+		return this->kbScrPos;
+	}
+
+	void SetKbScrPos(ting::uint newScrPos){
+		this->kbScrPos = newScrPos;
+	}
+
+	inline E_Timbre GetKbTimbre()const{
+		return this->kbTimbre;
+	}
+
+	inline void SetKbTimbre(E_Timbre newTimbre){
+		this->kbTimbre = newTimbre;
+	}
+
+
+
+
+
 	//Network settings
 private:
 	std::string username;
