@@ -73,7 +73,7 @@ public:
 	void PlayChannel(ting::Ref<Channel> ch);
 
 private:
-	class SoundThread : public ting::Thread{
+	class SoundThread : public ting::MsgThread{
 		ting::uint desiredBufferSizeInFrames;
 	public:
 		ting::Mutex chPoolMutex;
