@@ -33,6 +33,9 @@ std::string TimbreTypeToName(E_Timbre timbre){
 		case SAWTOOTH:
 			return "Sawtooth";
 			break;
+		case THEREMIN:
+			return "Theremin";
+			break;
 	}
 }
 
@@ -141,6 +144,9 @@ void MonotonicInstrumentHolder::ApplyTimbre(E_Timbre timbre){
 		case SAWTOOTH:
 			this->instr = aumiks::SawtoothInstrument::New();
 			break;
+		case THEREMIN:
+			this->instr = aumiks::ThereminInstrument::New();
+			break;
 	}
 }
 
@@ -161,6 +167,8 @@ E_Timbre MonotonicInstrumentHolder::GetCurrentTimbreType()const{
 		return PIANO;
 	}else if(this->instr.DynamicCast<aumiks::SawtoothInstrument>().IsValid()){
 		return SAWTOOTH;
+	}else if(this->instr.DynamicCast<aumiks::ThereminInstrument>().IsValid()){
+		return THEREMIN;
 	}else{
 		ASSERT_INFO(false, "unknown instrument")
 		return SINE_PLUS_ADSR;
